<?php

/**
 * Class CunningShortcode
 *
 * ショートコードを管理する
 */
class AffiliateButton {


	/**
	 * CunningShortcode constructor.
	 *
	 * 初期化する
	 */
	public function __construct() {
		add_shortcode( 'affiliate_link', array( $this, 'add_shortcode' ) );
		add_filter( 'mce_external_plugins', array( $this, "add_buttons" ) );
		add_filter( 'mce_buttons', array( $this, 'register_buttons' ) );
		add_action( 'admin_head-post-new.php', array( $this, 'admin_footer' ) );
		add_action( 'admin_head-post.php', array( $this, 'admin_footer' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}

	/**
	 * 管理画面のフッターに出力する
	 *
	 * @param $hook
	 *
	 * @return bool
	 */
	public function admin_footer( $hook ) {
		global $post_type;
		if ( $post_type !== "post" ) {
			return false;
		}
		?>

		<div class="remodal" data-remodal-id="modal"
		     data-remodal-options="hashTracking: false, closeOnOutsideClick: false">
			<button data-remodal-action="close" class="remodal-close"></button>

			<h3>ボタンの追加</h3>
			<table style="width: 100%;">
				<tbody>
					<tr>
						<th>
							<label for="affiliate_url">
								<strong>ボタン種類</strong>
							</label>
						</th>
						<td>
								<ul class="cmb2-radio-list cmb2-list" style="text-align: left; margin-top: 0; margin-bottom: 0;">
									<li>
										<input type="radio" class="cmb2-option" name="affiliate_insert_button_type" id="affiliate_insert_button_type1" value="prpr">
										<label for="affiliate_insert_button_type1">ぷるぷる</label>
									</li>
									<li>
										<input type="radio" class="cmb2-option" name="affiliate_insert_button_type" id="affiliate_insert_button_type2" value="normal" checked="checked">
										<label for="affiliate_insert_button_type2">ノーマル</label>
									</li>
								</ul>
						</td>

					</tr>
					<tr>
						<th>
							<label for="affiliate_url">
								<strong>リンクURL</strong>
							</label>
						</th>
						<td>
							<input type="url" id="affiliate_url" name="affiliate_url" style="width: 100%;" value=""/>
						</td>

					</tr>
					<tr>
						<th>
							<label for="affiliate_content">
								<strong>リンクテキスト</strong>
							</label>
						</th>
						<td>
							<input type="text" id="affiliate_content" value="公式サイトはこちら" name="affiliate_content" style="width: 100%;"/>
						</td>
					</tr>
					<tr>
						<th>
							<label for="affiliate_insert_button_color">
								<strong>ボタンカラー</strong>
							</label>
						</th>
						<td style="text-align: left;">
							<input type="text" name="affiliate_insert_button_color" id="affiliate_insert_button_color" value="#e12323">
						</td>
					</tr>
					<tr>
						<th>
							<label for="affiliate_size">
								<strong>サイズ</strong>
							</label>
						</th>
						<td style="text-align: left;">
							<select name="affiliate_size" id="affiliate_size">
								<option value="large">大</option>
								<option value="medium">中</option>
								<option value="small">小</option>
							</select>
						</td>
					</tr>
				</tbody>
			</table>
			<p style="text-align: center;">
				<button data-remodal-action="cancel" class="remodal-cancel">閉じる</button>
				<button data-remodal-action="confirm" class="remodal-confirm">挿入</button>
			</p>
		</div>

		<script type="text/javascript">
			(function ($) {
				window.afiiliate_remodalinstance = $('[data-remodal-id="modal"]').remodal();
			})(window.jQuery);

			jQuery(document).ready(function($){
				$('#affiliate_insert_button_color').wpColorPicker();
			});
		</script>
		<?php
	}

	/**
	 * スクリプトの登録
	 */
	public function enqueue_scripts( $hook ) {
		global $post_type;

		if ( $post_type !== "post" ) {
			return false;
		}

		wp_enqueue_style(
			'cunningadmin_remodal',
			"//cdnjs.cloudflare.com/ajax/libs/remodal/1.0.6/remodal.css",
			array(),
			null,
			false
		);

		wp_enqueue_style(
			'cunningadmin_remodaltheme',
			"//cdnjs.cloudflare.com/ajax/libs/remodal/1.0.6/remodal-default-theme.min.css",
			array(),
			null,
			false
		);

		wp_enqueue_script(
			'cunningadmin_remodal',
			"//cdnjs.cloudflare.com/ajax/libs/remodal/1.0.6/remodal.min.js",
			array( 'jquery' ),
			null,
			false
		);
	}

	/**
	 * ターゲットリンクのショートコードを登録
	 *
	 * @param array $attrs
	 * @param string $content
	 *
	 * @return string
	 */
	public function add_shortcode( $attrs = array(), $content = '' ) {

		$attrs = shortcode_atts( array(
			"href" => "",
		), $attrs );

		$tag = "";
		$tag .= '<a class="cunnningdragon_targetlink" href="' . esc_url( $attrs['href'] ) . '" target="_blank">';
		$tag .= $content;
		$tag .= '</a>';

		return $tag;

	}

	/**
	 * TinyMCE にボタンを追加
	 *
	 * @param $plugin_array
	 *
	 * @return mixed
	 */
	public function add_buttons( $plugin_array ) {
		$plugin_array['affiliatelinkbutton'] = get_template_directory_uri() . "/assets/js/affiliatelink-button.js";


		return $plugin_array;
	}

	/**
	 * TinyMCEに ボタンを登録
	 *
	 * @param $buttons
	 *
	 * @return mixed
	 */
	public function register_buttons( $buttons ) {

		array_push( $buttons, 'affiliatelink' );

		return $buttons;
	}

}
