<?php

/**
 * Class CunningShortcode
 *
 * ショートコードを管理する
 */
class CustomCardBox {

	/**
	 * CunningShortcode constructor.
	 *
	 * 初期化する
	 */
	public function __construct() {
		add_shortcode( 'customcardbox', array( $this, 'add_shortcode' ) );
		add_filter( 'mce_external_plugins', array( $this, "add_buttons" ) );
		add_filter( 'mce_buttons', array( $this, 'register_buttons' ) );
		add_action( 'admin_head-post-new.php', array( $this, 'admin_footer' ) );
		add_action( 'admin_head-post.php', array( $this, 'admin_footer' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}

	/**
	 * 管理画面のフッターに出力する
	 *
	 * @param $hook
	 *
	 * @return bool
	 */
	public function admin_footer( $hook ) {
		global $post_type;
		if ( $post_type !== "post" ) {
			return false;
		}
		?>
		<div>
		</div>

		<script type="text/javascript">
			(function ($) {
			})(window.jQuery);
		</script>
		<?php
	}

	/**
	 * スクリプトの登録
	 */
	public function enqueue_scripts( $hook ) {
		global $post_type;

		if ( $post_type !== "post" ) {
			return false;
		}

		wp_enqueue_style(
			'cunningadmin_remodal',
			"//cdnjs.cloudflare.com/ajax/libs/remodal/1.0.6/remodal.css",
			array(),
			null,
			false
		);

		wp_enqueue_style(
			'cunningadmin_remodaltheme',
			"//cdnjs.cloudflare.com/ajax/libs/remodal/1.0.6/remodal-default-theme.min.css",
			array(),
			null,
			false
		);

		wp_enqueue_script(
			'cunningadmin_remodal',
			"//cdnjs.cloudflare.com/ajax/libs/remodal/1.0.6/remodal.min.js",
			array( 'jquery' ),
			null,
			false
		);
	}

	/**
	 * ターゲットリンクのショートコードを登録
	 *
	 * @param array $attrs
	 * @param string $content
	 *
	 * @return string
	 */
	public function add_shortcode( $attrs = array(), $content = '' ) {
		$attrs = shortcode_atts( array("href" => ""), $attrs );

		$tag = "";
		$tag .= '<a class="cunnningdragon_targetlink" href="' . esc_url( $attrs['href'] ) . '" target="_blank">';
		$tag .= $content;
		$tag .= '</a>';

		return $tag;
	}

	/**
	 * TinyMCE にボタンを追加
	 *
	 * @param $plugin_array
	 *
	 * @return mixed
	 */
	public function add_buttons( $plugin_array ) {
		$plugin_array['customcardbox'] = get_template_directory_uri() . "/assets/js/custom-cardbox.js";
		return $plugin_array;
	}

	/**
	 * TinyMCEに ボタンを登録
	 *
	 * @param $buttons
	 *
	 * @return mixed
	 */
	public function register_buttons( $buttons ) {
		// array_unshift($buttons, 'customcardbox' );
		array_push( $buttons, 'customcardbox' );

		return $buttons;
	}
}
