<?php
use Mexitek\PHPColors\Color;

/**
 * Class CompareOptions
 * オプション管理クラス
 */
class CompareOptions {

	public $optionpage_key = "comparedefault";

	public $optionpage_metabox_id = "comparedefault";


	public $options_page = "";

	/**
	 * オプションの設定
	 * @var null
	 */
	public static $options = null;

	/**
	 * wp_options テーブルに保存するオプションキー
	 * @var string
	 */
	public $option_key = "compareppc_options";

	/**
	 * デフォルトのテーブル
	 * @var string
	 */
	public $default_table = "";


	public $post_id = false;

	public $compare_instance = null;
	public $post_instance = null;
	public $header_instance = null;
	public $themeoptions_instance = null;
	public $lp_instance = null;
	public $blog_instance = null;

	/**
	 * CompareOptions constructor.
	 * 初期化
	 */
	public function __construct() {


		$this->default_table = '<table class="table" style="width: 100%;"><tbody>
<tr><th class="width: 100px;">見出し</th><td>テキスト</td></tr>
<tr><th>見出し</th><td>テキスト</td></tr>
<tr><th>見出し</th><td>テキスト</td></tr>
<tr><th>見出し</th><td>テキスト</td></tr>
<tr><th>見出し</th><td>テキスト</td></tr>
</tbody>';

		add_action( 'admin_menu', array( $this, 'add_options_page' ) );
		add_action( 'admin_init', array( $this, 'optionpage_init' ) );
		add_action( 'wp', array( $this, "frontend_init" ), 10 );
		add_action( 'wp', array( $this, 'set_option' ), 11 );
		add_action( 'cmb2_init', array( $this, 'add_options_page_metabox' ) );

		// CMB2の設定登録
    add_action( 'cmb2_init', array( $this, 'header_customfield' ) );
		add_action( 'cmb2_init', array( $this, 'select_customfield' ) );

		add_action( 'cmb2_init', array( $this, 'order_customfield' ) );
		add_action( 'cmb2_init', array( $this, 'post_customfield' ) );
		add_action( 'cmb2_init', array( $this, 'compare_customfield' ) );
		add_action( 'cmb2_init', array( $this, 'lp_customfield' ) );
		add_action( 'cmb2_init', array( $this, 'blog_customfield' ) );

		// 投稿エディタを無効に
		add_action( 'init', array( $this, "disabled_post_editor" ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );


		add_action( 'wp_head', array( $this, "render_stylesheet" ) );


		add_action( "wp_head", array( $this, "add_trackingcode" ) );

	}

	/**
	 * 設定ページを追加
	 */
	public function optionpage_init() {
		register_setting( $this->optionpage_key, $this->optionpage_key );
	}

	/**
	 * オプションページを追加
	 */
	public function add_options_page() {
		$this->options_page = add_menu_page( "テーマ設定", "テーマ設定", 'manage_options', $this->optionpage_key, array(
			$this,
			'admin_page_display'
		) );
		add_action( "admin_print_styles-{$this->options_page}", array( 'CMB2_hookup', 'enqueue_cmb_css' ) );
	}

	/**
	 * Admin page markup. Mostly handled by CMB2
	 * @since  0.1.0
	 */
	public function admin_page_display() {
		?>
		<div class="wrap cmb2-options-page <?php echo $this->optionpage_key; ?>">
			<h2><?php echo esc_html( get_admin_page_title() ); ?></h2>
			<?php
			cmb2_metabox_form( $this->optionpage_metabox_id, $this->optionpage_key ); ?>
		</div>
		<?php
	}

	/**
	 * Register settings notices for display
	 *
	 * @since  0.1.0
	 *
	 * @param  int $object_id Option key
	 * @param  array $updated Array of updated fields
	 *
	 * @return void
	 */
	public function settings_notices( $object_id, $updated ) {
		if ( $object_id !== $this->optionpage_key || empty( $updated ) ) {
			return;
		}
		add_settings_error( $this->optionpage_key . '-notices', '', __( '設定を保存しました。', 'myprefix' ), 'updated' );
		settings_errors( $this->optionpage_key . '-notices' );
	}

	/**
	 * Public getter method for retrieving protected/private variables
	 * @since  0.1.0
	 *
	 * @param  string $field Field to retrieve
	 *
	 * @return mixed          Field value or exception is thrown
	 */
	public function __get( $field ) {
		// Allowed fields to retrieve
		if ( in_array( $field, array( 'key', 'metabox_id', 'title', 'options_page' ), true ) ) {
			return $this->{$field};
		}
		throw new Exception( 'Invalid property: ' . $field );
	}

	/**
	 * フロントエンドの初期化
	 */
	public function frontend_init() {
		$this->set_post_id();
	}

	/**
	 * 管理画面のスクリプトを登録
	 */
	public function admin_scripts( $hook ) {

		if ( ! in_array( $hook, array(
			"post.php",
			"post-new.php"
		) )
		) {
			return false;
		}

    $my_theme = wp_get_theme();
		wp_enqueue_script( 'compare_post_edit', get_template_directory_uri() . "/assets/js/admin.js", array(),  $my_theme->get( 'Version' ));
	}

	/**
	 * 投稿エディタを非表示に
	 */
	public function disabled_post_editor() {
		remove_post_type_support( 'post', 'editor' );
	}


	/**
	 * テーマ設定ページのオプション一覧
	 * * default_header_display
	 * * default_header_image
	 * * default_header_bgcolor
	 * * default_header_text
	 * * default_tracking
	 * * default_table
	 * @since  0.1.0
	 */
	function add_options_page_metabox() {

		// 保存時の注意文を変更する
		add_action( "cmb2_save_options-page_fields_{$this->optionpage_metabox_id}", array(
			$this,
			'settings_notices'
		), 10, 2 );

		$this->themeoptions_instance = new_cmb2_box( array(
			'id'         => $this->optionpage_metabox_id,
			'hookup'     => false,
			'cmb_styles' => false,
			'show_on'    => array(
				'key'   => 'options-page',
				'value' => array( $this->optionpage_key, )
			),
		) );

		$this->themeoptions_instance->add_field( array(
			'name' => '初期設定',
			'desc' => '商材ページの初期値を設定してください。トップページ、カテゴリページ、各商材追加ページでの初期値に反映されます。',
			'type' => 'title',
			'id'   => 'default_title'
		) );

		$this->themeoptions_instance->add_field( array(
			'name'    => __( 'テーマカラー ', 'cmb2' ),
			'id'      => 'default_color',
			'type'    => 'colorpicker',
			'default' => "#b71742"
		) );

		$this->themeoptions_instance->add_field( array(
			'name'        => __( '背景カラー', 'cmb2' ),
			'description' => "背景色を設定してください。",
			'id'          => 'default_bgcolor',
			'type'        => 'bgcolorbpicker',
			'default'     => "#ffffff"
		) );


		$this->themeoptions_instance->add_field( array(
			'name'    => __( 'ヘッダー : 表示', 'cmb2' ),
			'id'      => 'default_header_display',
			'type'    => 'radio',
			'options' => array(
				'true'  => '表示',
				'false' => '非表示',
			),
			'default' => "false"
		) );

		$this->themeoptions_instance->add_field( array(
			'name' => __( 'ヘッダー : 画像', 'cmb2' ),
			'id'   => 'default_header_image',
			'type' => 'file',
		) );

		$this->themeoptions_instance->add_field( array(
			'name'    => __( 'ヘッダー : 背景色', 'cmb2' ),
			'id'      => 'default_header_bgcolor',
			'type'    => 'colorpicker',
			'default' => "#f6f6f6"
		) );

		$this->themeoptions_instance->add_field( array(
			'name'    => __( 'ヘッダー : 説明文', 'cmb2' ),
			'id'      => 'default_header_description',
			'type'    => 'text',
			'default' => get_bloginfo( 'description' )
		) );

		$this->themeoptions_instance->add_field( array(
			'name'    => __( 'ヘッダー : ロゴ', 'cmb2' ),
			'id'      => 'default_header_text',
			'type'    => 'text',
			'default' => get_bloginfo( 'title' )
		) );

		$this->themeoptions_instance->add_field( array(
			'name'    => __( 'ヘッダー : ロゴカラー', 'cmb2' ),
			'id'      => 'default_header_text_color',
			'type'    => 'colorpicker',
			'default' => "",
		) );


		$this->themeoptions_instance->add_field( array(
			'name' => __( 'トラッキングタグ', 'cmb2' ),
			'id'   => 'default_tracking',
			'type' => 'textarea_code',
		) );

		$this->themeoptions_instance->add_field( array(
			'name'    => __( 'サムネイル画像', 'cmb2' ),
			'id'      => 'default_thumbnail',
			'type'    => 'file',
			'default' => get_template_directory_uri() . "/assets/images/nophoto.png"
		) );

		$this->themeoptions_instance->add_field( array(
			'name'        => __( 'テーブル初期値', 'cmb2' ),
			'id'          => 'default_table',
			'description' => "各アフィリエイトのテーブルの初期値に反映されます。",
			'type'        => 'wysiwyg',
			'default'     => $this->default_table,
		) );


	}


	/**
	 * 商材タイプを選択
	 * * select_type
	 */
	public function order_customfield() {

		$prefix = 'select_';

		$cmb = new_cmb2_box( array(
			'id'           => "order_metabox",
			'title'        => __( '運営者について', 'cmb2' ),
			'object_types' => array( 'page', ),
			'show_on'      => array( 'key' => 'id', 'value' => get_option( 'epigone_order_id' ) ),
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true,
		) );

		$cmb->add_field( array(
			'name' => __( 'サイト運営者', 'cmb2' ),
			'id'   => 'order_1',
			'type' => 'textarea',
		) );

		$cmb->add_field( array(
			'name' => __( '所在地', 'cmb2' ),
			'id'   => 'order_2',
			'type' => 'textarea',
		) );

		$cmb->add_field( array(
			'name' => __( '連絡先', 'cmb2' ),
			'id'   => 'order_3',
			'type' => 'textarea',
		) );


		$cmb->add_field( array(
			'name' => __( 'お申し込み方法', 'cmb2' ),
			'id'   => 'order_4',
			'type' => 'textarea',
		) );


		$cmb->add_field( array(
			'name' => __( '商品引渡し方法', 'cmb2' ),
			'id'   => 'order_5',
			'type' => 'textarea',
		) );

		$cmb->add_field( array(
			'name' => __( '商品引渡し時期', 'cmb2' ),
			'id'   => 'order_6',
			'type' => 'textarea',
		) );


		$cmb->add_field( array(
			'name' => __( 'お支払い方法', 'cmb2' ),
			'id'   => 'order_7',
			'type' => 'textarea',
		) );

		$cmb->add_field( array(
			'name' => __( '返品・不良品について', 'cmb2' ),
			'id'   => 'order_8',
			'type' => 'textarea',
		) );

		$cmb->add_field( array(
			'name' => __( '責任の有無', 'cmb2' ),
			'id'   => 'order_9',
			'type' => 'textarea',
		) );


	}


	/**
	 * 商材タイプを選択
	 * * select_type
	 */
	public function select_customfield() {

		$prefix = 'select_';

		$this->type_instance = new_cmb2_box( array(
			'id'           => "select_metabox",
			'title'        => __( '商材タイプ設定', 'cmb2' ),
			'object_types' => array( 'post', ),
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => false,
		) );

		$this->type_instance->add_field( array(
			'name'    => __( '商材タイプを選択してください', 'cmb2' ),
			'id'      => 'select_type',
			'type'    => 'radio',
			'options' => array(
        'compare' => '商品比較記事として作成',
				'post'    => '単品商品として作成',
				// 'lp'      => 'LP式として作成',
				'blog'    => 'ブログとして作成'
			),
			'default' => "post"
		) );

	}

	/**
	 * ヘッダーのカスタムフィールド
	 *
	 * * header_display
	 * * header_image
	 * * header_bgcolor
	 * * header_text
	 */
	public function header_customfield() {

		$this->header_instance = new_cmb2_box( array(
			'id'           => "header_metabox",
			'title'        => __( '共通設定', 'cmb2' ),
			'object_types' => array( 'post', ),
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true,
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'ヘッダー : 表示', 'cmb2' ),
			'id'      => 'header_display',
			'type'    => 'radio',
			'options' => array(
				'true'  => '表示',
				'false' => '非表示',
			),
			'default' => "false"
		) );

		$this->header_instance->add_field( array(
			'name' => __( 'ヘッダー : 画像', 'cmb2' ),
			'id'   => 'header_image',
			'type' => 'file',
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'ヘッダー : 背景色', 'cmb2' ),
			'id'      => 'header_bgcolor',
			'type'    => 'colorpicker',
			'default' => '#e12323'
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'ヘッダー : テキスト', 'cmb2' ),
			'id'      => 'header_text',
			'type'    => 'text',
			'default' => ""
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'ヘッダー : テキストカラー', 'cmb2' ),
			'id'      => 'header_text_color',
			'type'    => 'colorpicker',
			'default' => "#ffffff"
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'ボディ : 背景色', 'cmb2' ),
			'id'      => 'body_bgcolor',
			'type'    => 'bgcolorpicker',
			'default' => "#ffffff"
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'フッター固定ボタン：表示', 'cmb2' ),
			'id'      => 'footerfix_button_display',
			'type'    => 'radio',
			'options' => array(
				'true'  => '表示',
				'false' => '非表示',
			),
			'default' => "false"
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'フッター固定ボタン：種類', 'cmb2' ),
			'id'      => 'footerfix_button_type',
			'type'    => 'radio',
			'options' => array(
				'2'  => 'ぷるぷる',
				'1' => 'ノーマル',
			),
			'default' => "2"
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'フッター固定ボタン：アフィリエイト URL', 'cmb2' ),
			'id'      => 'footerfix_affiliate_link',
			'type'    => 'text',
			'default' => ""
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'フッター固定ボタン：テキスト', 'cmb2' ),
			'id'      => 'footerfix_affiliate_text',
			'type'    => 'text',
			'default' => "公式サイトはこちら"
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'フッター固定ボタン：ボタンカラー', 'cmb2' ),
			// 'desc'    => __( 'アフィリエイトボタンのカラーを設定してください', 'cmb2' ),
			'id'      => 'footerfix_affiliate_button_color',
			'type'    => 'colorpicker',
			'default' => "#e12323"
		) );

		// $this->header_instance->add_field( array(
		// 	'name'    => __( 'SNSボタン：表示', 'cmb2' ),
		// 	'id'      => 'sns_buttons_display',
		// 	'type'    => 'radio',
		// 	'options' => array(
		// 		'true'  => '表示',
		// 		'false' => '非表示'
		// 	),
		// 	'default' => "false"
		// ) );

		$this->header_instance->add_field( array(
			'name'    => __( 'SNSボタン：表示位置', 'cmb2' ),
			'id'      => 'sns_buttons_display_position',
			'type'    => 'multicheck',
			'options' => array(
				'header'=> '記事の先頭に表示',
				'footer'=> '記事の最後に表示'
			)
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'SNSボタン：Twitterカウント数', 'cmb2' ),
			'id'      => 'sns_buttons_twitter_count',
			'type'    => 'text',
			'default' => ""
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'SNSボタン：Facebookカウント数', 'cmb2' ),
			'id'      => 'sns_buttons_facebook_count',
			'type'    => 'text',
			'default' => ""
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'SNSボタン：Google+カウント数', 'cmb2' ),
			'id'      => 'sns_buttons_googleplus_count',
			'type'    => 'text',
			'default' => ""
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'SNSボタン：はてブカウント数', 'cmb2' ),
			'id'      => 'sns_buttons_hatebu_count',
			'type'    => 'text',
			'default' => ""
		) );

		$this->header_instance->add_field( array(
			'name'    => __( 'SNSボタン：pocketカウント数', 'cmb2' ),
			'id'      => 'sns_buttons_pocket_count',
			'type'    => 'text',
			'default' => ""
		) );

    $this->header_instance->add_field( array(
      'name'    => __( 'SNSボタン：feedlyカウント数', 'cmb2' ),
      'id'      => 'sns_buttons_feedly_count',
      'type'    => 'text',
      'default' => ""
    ) );

    $this->header_instance->add_field( array(
      'name'    => __( 'レコメンドメッセージ', 'cmb2' ),
      'id'      => 'recommend_msg',
      'type'    => 'text',
      'default' => "この商品を買った人はこんな商品も見ています"
    ) );

    // $this->header_instance->add_field( array(
    //  'name' => __( 'トラッキングタグ', 'cmb2' ),
    //  'id'   => 'tracking',
    //  'type' => 'textarea_code',
    // ) );
    $this->header_instance->add_field( array(
      'name' => __( 'フリースペース（比較形式用）', 'cmb2' ),
      'id'   => 'freespace',
      'type' => 'wysiwyg',
      'options' => array( 'textarea_rows' => 10, ),
    ) );
		$this->header_instance->add_field( array(
			'name' => __( '備考欄', 'cmb2' ),
			'desc' => __( '', 'cmb2' ),
			'id'   => 'memo',
			'type' => 'textarea',
		) );

	}

	/**
	 * 投稿のカスタムフィールド設定
	 *
	 * * affiliate_color
	 * * affiliate_title
	 * * affiliate_link
	 * * affiliate_text
	 * * affiliate_button_text
	 * * affiliate_button_size
	 * * affiliate_table
	 */
	public function post_customfield() {

		$prefix = 'affiliate_';

		/**
		 * Initiate the metabox
		 */
		$this->post_instance = new_cmb2_box( array(
			'id'           => $prefix . "metabox",
			'title'        => __( '商品設定', 'cmb2' ),
			'object_types' => array( 'post', ),
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true,
		) );


		$this->post_instance->add_field( array(
			'name' => __( 'カラー設定', 'cmb2' ),
			'desc' => __( 'アフィリエイトページのカラーを設定してください。', 'cmb2' ),
			'id'   => 'affiliate_color',
			'type' => 'colorpicker',
		) );

		$this->post_instance->add_field( array(
			'name' => __( 'アフィリエイトURL', 'cmb2' ),
			'id'   => 'affiliate_link',
			'type' => 'text',

		) );

		$this->post_instance->add_field( array(
			'name' => __( '説明文タイトル', 'cmb2' ),
			'id'   => 'affiliate_title',
			'type' => 'text',
		) );

		$this->post_instance->add_field( array(
			'name' => __( '説明文テキスト', 'cmb2' ),
			'id'   => 'affiliate_text',
			'type' => 'wysiwyg',
		) );

		$this->post_instance->add_field( array(
			'name'    => __( 'ボタン種類', 'cmb2' ),
			'id'      => 'affiliate_button_type',
			'type'    => 'radio',
			'options' => array(
				'prpr'  => 'ぷるぷる',
				'normal'=> 'ノーマル',
			),
			'default' => "prpr"
		) );

		$this->post_instance->add_field( array(
			'name'        => __( 'ボタンテキスト', 'cmb2' ),
			"description" => "(14文字程度を目安にしてください)",
			'id'          => 'affiliate_button_text',
			'default'     => "公式サイトはこちら",
			'type'        => 'text',
		) );

		$this->post_instance->add_field( array(
			'name'    => __( 'ボタンサイズ', 'cmb2' ),
			'id'      => 'affiliate_button_size',
			'type'    => 'radio',
			'default' => 'large',
			'options' => array(
				'large'  => '大',
				'medium' => '中',
				'small'  => '小'
			)
		) );

		$this->post_instance->add_field( array(
			'name'    => __( 'ボタンカラー', 'cmb2' ),
			'desc'    => __( 'アフィリエイトボタンのカラーを設定してください', 'cmb2' ),
			'id'      => 'affiliate_button_color',
			'type'    => 'colorpicker',
			"deufalt" => "#ED0B0B"
		) );

//		$this->post_instance->add_field( array(
//			'name'    => __( '商品詳細テーブル', 'cmb2' ),
//			'id'      => 'affiliate_table',
//			'type'    => 'wysiwyg',
//			'options' => array(
//				'wpautop' => false,
//			),
//			'default' => $this->get_option( 'default_table' ) ? $this->get_option( 'default_table' ) : $this->default_table,
//		) );


	}

	/**
	 * 投稿のカスタムフィールド設定
	 *
	 * * affiliate_color
	 * * affiliate_title
	 * * affiliate_link
	 * * affiliate_text
	 * * affiliate_button_text
	 * * affiliate_button_size
	 * * affiliate_table
	 */
	public function lp_customfield() {

		$prefix = 'lp_';

		/**
		 * Initiate the metabox
		 */
		$this->lp_instance = new_cmb2_box( array(
			'id'           => $prefix . "metabox",
			'title'        => __( '商品設定 - LP式', 'cmb2' ),
			'object_types' => array( 'post', ),
			'context'      => 'normal',
			'priority'     => 'low',
			'show_names'   => true,
		) );


		$this->lp_instance->add_field( array(
			'name' => __( 'カラー設定', 'cmb2' ),
			'desc' => __( 'アフィリエイトページのカラーを設定してください。', 'cmb2' ),
			'id'   => 'lp_color',
			'type' => 'colorpicker',
		) );


		$this->lp_instance->add_field( array(
			'name' => __( '説明文、または画像', 'cmb2' ),
			'id'   => 'lp_text',
			'type' => 'wysiwyg',
		) );


	}

	/**
	 * 比較ページのカスタムフィールド設定
	 *
	 * * compare_color
	 * * compare_header_image
	 * * compare_table
	 * * compare_item_title
	 * * compare_item_image
	 * * compare_item_link
	 * * compare_item_button
	 * * compare_item_table
	 * * compare_item_catchcopy
	 * * compare_item_paragrafh
	 */
	public function compare_customfield() {


		$prefix = 'compare_';

		$this->compare_instance = new_cmb2_box( array(
			'id'           => $prefix . "metabox",
			'title'        => __( '商品設定 - 商品比較記事設定', 'cmb2' ),
			'object_types' => array( 'post', ),
			'context'      => 'normal',
			'priority'     => 'high',
			'show_names'   => true,
		) );

		$this->compare_instance->add_field( array(
			'name'    => __( 'カラー設定', 'cmb2' ),
			'desc'    => __( 'アフィリエイトページのカラーを設定してください。', 'cmb2' ),
			'id'      => 'compare_color',
			'type'    => 'colorpicker',
			'default' => "#e12323"
		) );

		// $this->compare_instance->add_field( array(
		// 	'name'    => __( 'ランキング番号の出力', 'cmb2' ),
		// 	'id'      => 'compare_rank_display',
		// 	'type'    => 'radio',
		// 	'default' => 'true',
		// 	'options' => array(
		// 		'true'  => '表示する',
		// 		'false' => '表示しない',
		// 	)
		// ) );

    global $post;

// $compare_sort_btn2 = get_post_meta($_GET['post'], "compare_sort_btn2", true);//CompareOptions::get( "compare_sort_btn2" );
// $compare_sort_btn3 = get_post_meta($_GET['post'], "compare_sort_btn3", true);//CompareOptions::get( "compare_sort_btn2" );
    $this->compare_instance->add_field( array(
      'name'    => '並び替えボタン1',
      'id'      => 'compare_sort_btn1',
      'type'       => 'text_medium',
      'attributes' => array(
        'class'       => 'compare_sort_btn_name',
        'data-tid'    => '1',
        'placeholder' => '例：価格'
      ),
    ) );
    $this->compare_instance->add_field( array(
      'name'    => '並び替えボタン2',
      'id'      => 'compare_sort_btn2',
      'type'       => 'text_medium',
      'attributes' => array(
        'class' => 'compare_sort_btn_name',
        'data-tid'    => '2',
        'placeholder' => '例：送料'
      ),
    ) );
    $this->compare_instance->add_field( array(
      'name'    => '並び替えボタン3',
      'id'      => 'compare_sort_btn3',
      'type'       => 'text_medium',
      'attributes' => array(
        'class' => 'compare_sort_btn_name',
        'data-tid'    => '3',
        'placeholder' => '例：代引手数料'
      ),
    ) );
    $this->compare_instance->add_field( array(
      'name'    => '並び替えボタン4',
      'id'      => 'compare_sort_btn4',
      'type'       => 'text_medium',
      'attributes' => array(
        'class' => 'compare_sort_btn_name',
        'data-tid'    => '4',
        'placeholder' => '例：お届け日数'
      ),
    ) );
    $this->compare_instance->add_field( array(
      'name'    => '並び替えボタン5',
      'id'      => 'compare_sort_btn5',
      'type'       => 'text_medium',
      'attributes' => array(
        'class' => 'compare_sort_btn_name',
        'data-tid'    => '5',
        'placeholder' => '例：支払い方法'
      ),
    ) );
    // $this->compare_instance->add_field( array(
    //   'name'    => '並び替えボタン6',
    //   'id'      => 'compare_sort_btn6',
    //   'type'       => 'text_medium',
    //   'attributes' => array(
    //     'class' => 'compare_sort_btn_name',
    //     'data-tid'    => '6',
    //     'placeholder' => '例：保証期間'
    //   ),
    // ) );
    // $this->compare_instance->add_field( array(
    //   'id'      => 'compare_sort_btn2',
    //   'type'    => 'hidden',
    // ) );
    // $this->compare_instance->add_field( array(
    //   'id'      => 'compare_sort_btn3',
    //   'type'    => 'hidden',
    // ) );

		$group_field_id = $this->compare_instance->add_field( array(
			'id'      => 'compare_table',
			'type'    => 'group',
			'name'    => "商品情報を入力してください",
			'options' => array(
				'group_title'   => __( '商品 {#}', 'cmb' ),
				'add_button'    => __( '新しい商品を追加', 'cmb' ),
				'remove_button' => __( '商品を削除', 'cmb' ),
				'sortable'      => true,
			),
		) );

		$this->compare_instance->add_group_field( $group_field_id, array(
			'name'       => '商品名',
			'id'         => 'compare_item_title',
			'type'       => 'text',
			'attributes' => array(
				'placeholder' => '商品名を入力してください',
        'class'       => 'regular-text compare_item_clear_val'
			),
		) );

		$this->compare_instance->add_group_field( $group_field_id, array(
			'name'       => '商品画像',
			'id'         => 'compare_item_image',
			'type'       => 'file',
			'before_row' => '<div class="clearfix"><div class="left">',
			'attributes' => array(
				'placeholder' => '商品画像を設定してください。',
        'class'       => 'compare_item_clear_val cmb2-upload-file'
			),
		) );

		$this->compare_instance->add_group_field( $group_field_id, array(
			'name'    => __( 'ボタン種類', 'cmb2' ),
			'id'      => 'compare_item_button_type',
			'type'    => 'radio',
			'options' => array(
				'prpr'  => 'ぷるぷる',
				'normal'=> 'ノーマル',
			),
			'default' => "prpr"
		) );

		$this->compare_instance->add_group_field( $group_field_id, array(
			'name'       => 'アフィリエイトリンク',
			'id'         => 'compare_item_link',
			'type'       => 'text_url',
			'attributes' => array(
				'placeholder' => 'アフィリエイトリンクを入力',
        'class'       => 'cmb2-text-url cmb2-text-medium regular-text compare_item_clear_val'
			),
		) );

		$this->compare_instance->add_group_field( $group_field_id, array(
			'name'       => 'ボタンテキスト',
			'id'         => 'compare_item_button',
			'type'       => 'text',
			'default'    => '公式サイトはこちら',
			'attributes' => array(
//				'value'       => "公式サイトはこちら",
				'placeholder' => 'ボタンテキストを入力してください'
			),
		) );

		$this->compare_instance->add_group_field( $group_field_id, array(
			'name'      => 'ボタンカラー',
			'id'        => 'compare_item_button_color',
			'type'      => 'colorpicker',
			'after_row' => '</div>',
      'default'   => "#e12323"
		) );

		// $this->compare_instance->add_group_field( $group_field_id, array(
		// 	'name'       => '商材テーブル',
		// 	'id'         => 'compare_item_table',
		// 	'type'       => 'wysiwyg',
		// 	'before_row' => '<div class="right">',
		// 	'after_row'  => '</div></div>',
		// 	'options'    => array(
		// 		'media_buttons' => false,
		// 		'dfw'           => false,
		// 		'textarea_rows' => 12,
		// 	),
		// 	'attributes' => array(
		// 		'placeholder' => '商材テーブル情報を入力してください。',
		// 	),
		// 	'default'    => $this->default_table,
		// ) );

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブル見出し1',
      'id'         => 'compare_item_th1',
      'type'       => 'text_medium',
      'before_row' => '<div class="right compare_item_tables"><h5>商材テーブル情報</h5><table><tr><th>',
      'after_row'  => '</th><td>',
      'attributes' => array(
        'placeholder' => '見出し1',
      ),
    ));

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブルテキスト1',
      'id'         => 'compare_item_td1',
      'type'       => 'text_medium',
      'after_row'  => '</td></tr>',
      'attributes' => array(
        'placeholder' => 'テキスト1',
        'class'       => 'compare_item_td_text cmb2-text-medium',
      ),
    ));

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブル見出し2',
      'id'         => 'compare_item_th2',
      'type'       => 'text_medium',
      'before_row' => '<tr><th>',
      'after_row'  => '</th><td>',
      'attributes' => array(
        'placeholder' => '見出し2',
      ),
    ));

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブルテキスト2',
      'id'         => 'compare_item_td2',
      'type'       => 'text_medium',
      'after_row'  => '</td></tr>',
      'attributes' => array(
        'placeholder' => 'テキスト2',
        'class'       => 'compare_item_td_text cmb2-text-medium',
      ),
    ));

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブル見出し3',
      'id'         => 'compare_item_th3',
      'type'       => 'text_medium',
      'before_row' => '<tr><th>',
      'after_row'  => '</th><td>',
      'attributes' => array(
        'placeholder' => '見出し3',
      ),
    ));

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブルテキスト3',
      'id'         => 'compare_item_td3',
      'type'       => 'text_medium',
      'after_row'  => '</td></tr>',
      'attributes' => array(
        'placeholder' => 'テキスト3',
        'class'       => 'compare_item_td_text cmb2-text-medium',
      ),
    ));

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブル見出し4',
      'id'         => 'compare_item_th4',
      'type'       => 'text_medium',
      'before_row' => '<tr><th>',
      'after_row'  => '</th><td>',
      'attributes' => array(
        'placeholder' => '見出し4',
      ),
    ));

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブルテキスト4',
      'id'         => 'compare_item_td4',
      'type'       => 'text_medium',
      'after_row'  => '</td></tr>',
      'attributes' => array(
        'placeholder' => 'テキスト4',
        'class'       => 'compare_item_td_text cmb2-text-medium',
      ),
    ));

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブル見出し5',
      'id'         => 'compare_item_th5',
      'type'       => 'text_medium',
      'before_row' => '<tr><th>',
      'after_row'  => '</th><td>',
      'attributes' => array(
        'placeholder' => '見出し5',
      ),
    ));

    $this->compare_instance->add_group_field( $group_field_id, array(
      // 'name'       => '商材テーブルテキスト5',
      'id'         => 'compare_item_td5',
      'type'       => 'text_medium',
      'after_row'  => '</td></tr></table></div></div>',
      'attributes' => array(
        'placeholder' => 'テキスト5',
        'class'       => 'compare_item_td_text cmb2-text-medium',
      ),
    ));


    $compare_sort_order_options = array();
    for ($i=1; $i < 101; $i++) { 
      $compare_sort_order_options[$i] = $i;
    }

    $this->compare_instance->add_group_field( $group_field_id, array(
      'name'       => 'ソート',
      'id'         => 'compare_sort_order1',
      'before'     => '<label>並び替えボタン1 の順位：</label><label class="compare_sort_order1 compare_sort_order_labels">並び替えボタン1を入力してください</label> ',
      'type'       => 'select',
      'options'    => $compare_sort_order_options,
      'row_classes'=> "compare_sort_orders",
      'attributes' => array(
        'class'       => 'cmb2_select compare_item_val_1'
      ),
    ) );

    $this->compare_instance->add_group_field( $group_field_id, array(
      'name'       => 'ソート',
      'id'         => 'compare_sort_order2',
      'before'     => '<label>並び替えボタン2 の順位：</label><label class="compare_sort_order2 compare_sort_order_labels">並び替えボタン2を入力してください</label> ',
      'type'       => 'select',
      'options'    => $compare_sort_order_options,
      'row_classes'=> "compare_sort_orders",
      'attributes' => array(
        'class'       => 'cmb2_select compare_item_val_1'
      ),
    ) );

    $this->compare_instance->add_group_field( $group_field_id, array(
      'name'       => 'ソート',
      // 'description'=> 'ソート順位は後から追加・変更しやすいよう1位から順に10,20,30とある程度、値に間隔を空けて設定する事をおすすめします。',
      'id'         => 'compare_sort_order3',
      'before'     => '<label>並び替えボタン3 の順位：</label><label class="compare_sort_order3 compare_sort_order_labels">並び替えボタン3を入力してください</label> ',
      'type'       => 'select',
      'options'    => $compare_sort_order_options,
      'row_classes'=> "compare_sort_orders",
      'attributes' => array(
        'class'       => 'cmb2_select compare_item_val_1'
      ),
    ) );

    $this->compare_instance->add_group_field( $group_field_id, array(
      'name'       => 'ソート',
      // 'description'=> 'ソート順位は後から追加・変更しやすいよう1位から順に10,20,30とある程度、値に間隔を空けて設定する事をおすすめします。',
      'id'         => 'compare_sort_order4',
      'before'     => '<label>並び替えボタン4 の順位：</label><label class="compare_sort_order4 compare_sort_order_labels">並び替えボタン4を入力してください</label> ',
      'type'       => 'select',
      'options'    => $compare_sort_order_options,
      'row_classes'=> "compare_sort_orders",
      'attributes' => array(
        'class'       => 'cmb2_select compare_item_val_1'
      ),
    ) );

    $this->compare_instance->add_group_field( $group_field_id, array(
      'name'       => 'ソート',
      // 'description'=> 'ソート順位は後から追加・変更しやすいよう1位から順に10,20,30とある程度、値に間隔を空けて設定する事をおすすめします。',
      'id'         => 'compare_sort_order5',
      'before'     => '<label>並び替えボタン5 の順位：</label><label class="compare_sort_order5 compare_sort_order_labels">並び替えボタン5を入力してください</label> ',
      'type'       => 'select',
      'options'    => $compare_sort_order_options,
      'row_classes'=> "compare_sort_orders",
      'attributes' => array(
        'class'       => 'cmb2_select compare_item_val_1'
      ),
    ) );

    // $this->compare_instance->add_group_field( $group_field_id, array(
    //   'name'       => 'ソート',
    //   // 'description'=> 'ソート順位は後から追加・変更しやすいよう1位から順に10,20,30とある程度、値に間隔を空けて設定する事をおすすめします。',
    //   'id'         => 'compare_sort_order6',
    //   'before'     => '<label>並び替えボタン6 の順位：</label><label class="compare_sort_order6 compare_sort_order_labels">並び替えボタン6を入力してください</label> ',
    //   'type'       => 'select',
    //   'options'    => $compare_sort_order_options,
    //   'row_classes'=> "compare_sort_orders",
    //   'attributes' => array(
    //     'class'       => 'cmb2_select compare_item_val_1'
    //   ),
    // ) );

    $this->compare_instance->add_group_field( $group_field_id, array(
      'name'       => '説明文タイトル',
      'id'         => 'compare_item_catchcopy',
      'type'       => 'text_medium',
      'attributes' => array(
        'placeholder' => '説明文タイトルを入力してください。',
        'class'       => 'cmb2-text-large compare_item_clear_val'
      ),
    ) );

		$this->compare_instance->add_group_field( $group_field_id, array(
			'name'    => '説明文',
			'id'      => 'compare_item_paragrafh',
			'type'    => 'wysiwyg',
			'options' => array( 'textarea_rows' => 10, ),
		) );
	}

	/**
	 * 投稿のカスタムフィールド設定
	 *
	 * * 
	 */
	public function blog_customfield() {

		$prefix = 'blog_';

		/**
		 * Initiate the metabox
		 */
		$this->blog_instance = new_cmb2_box( array(
			'id'           => $prefix . "metabox",
			'title'        => __( '商品設定 - ブログ', 'cmb2' ),
			'object_types' => array( 'post', ),
			'context'      => 'normal',
			'priority'     => 'low',
			'show_names'   => false,
		) );

		$this->blog_instance->add_field( array(
			'name' => __( 'カラー設定', 'cmb2' ),
			'desc' => __( 'アフィリエイトページのカラーを設定してください。', 'cmb2' ),
			'id'   => 'blog_color',
			'type' => 'colorpicker',
		) );

		$this->blog_instance->add_field( array(
			'name' => __( '説明文', 'cmb2' ),
			'id'   => 'blog_text',
			'type' => 'wysiwyg',
		) );


	}


	/**
	 * 投稿IDをセットする
	 */
	public function set_post_id() {
		global $post;
		if ( is_home() || is_front_page() || is_page() || is_archive() ) {
			$this->post_id = false;
		} else {
			$this->post_id = get_the_ID();
		}
	}

	/**
	 * オプションをセットする
	 *
	 * @param $key
	 * @param $valuea
	 */
	public function set_option() {


		static::$options = array();

		static::$options['select_type'] = $this->get_meta( "select_type", "post" );

		switch ( static::$options['select_type'] ) {

			case "compare" :

				foreach ( $this->compare_instance->meta_box["fields"] as $value ) {
					static::$options[ $value["id"] ] = $this->get_meta( $value["id"],
						( isset( $value["default"] ) ? $value["default"] : "" ) );

				}

				foreach ( $this->header_instance->meta_box["fields"] as $value ) {
					static::$options[ $value["id"] ] = $this->get_meta( $value["id"],
						( isset( $value["default"] ) ? $value["default"] : "" ) );
				}

				break;

			case "post" :

				foreach ( $this->post_instance->meta_box["fields"] as $value ) {
					static::$options[ $value["id"] ] = $this->get_meta( $value["id"],
						( isset( $value["default"] ) ? $value["default"] : "" ) );
					if ( $value["id"] == "header_bgcolor" ) {
					}
				}

				foreach ( $this->header_instance->meta_box["fields"] as $value ) {
					static::$options[ $value["id"] ] = $this->get_meta( $value["id"],
						( isset( $value["default"] ) ? $value["default"] : "" ) );
				}

			case "lp" :

				foreach ( $this->lp_instance->meta_box["fields"] as $value ) {
					static::$options[ $value["id"] ] = $this->get_meta( $value["id"],
						( isset( $value["default"] ) ? $value["default"] : "" ) );
					if ( $value["id"] == "header_bgcolor" ) {
					}
				}

				foreach ( $this->header_instance->meta_box["fields"] as $value ) {
					static::$options[ $value["id"] ] = $this->get_meta( $value["id"],
						( isset( $value["default"] ) ? $value["default"] : "" ) );
				}

			case "blog" :
				foreach ( $this->blog_instance->meta_box["fields"] as $value ) {
					static::$options[ $value["id"] ] = $this->get_meta( $value["id"],
						( isset( $value["default"] ) ? $value["default"] : "" ) );
					if ( $value["id"] == "header_bgcolor" ) {
					}
				}

				foreach ( $this->header_instance->meta_box["fields"] as $value ) {
					static::$options[ $value["id"] ] = $this->get_meta( $value["id"],
						( isset( $value["default"] ) ? $value["default"] : "" ) );
				}

			default :
				break;

		}

		foreach ( $this->themeoptions_instance->meta_box["fields"] as $value ) {
			static::$options[ $value["id"] ] = $this->get_option( $value["id"],
				( isset( $value["default"] ) ? $value["default"] : "" ) );
		}
	}

	/**
	 * get_post_metaのラッパー
	 *
	 * @param $key
	 *
	 * @return mixed
	 */
	public function get_meta( $key, $default = "" ) {

		$postmeta = get_post_meta( $this->post_id, $key, true );

		if ( $postmeta ) {
			return $postmeta;
		}

		return $default;

	}

	/**
	 * オプションを取得する
	 *
	 * @param $key
	 * @param string $default
	 */
	public function get_option( $key, $default = "" ) {

		$opt = cmb2_get_option( $this->optionpage_key, $key );
		if ( $opt ) {
			return $opt;
		}

		return $default;
	}

	/**
	 * オプションを取得
	 *
	 * @param $key
	 *
	 * @return bool
	 */
	public static function get( $key ) {
		if ( isset( static::$options[ $key ] ) ) {
			return static::$options[ $key ];
		} else {
			return false;
		}
	}

	public function add_trackingcode() {
		$trackingcode = self::get_meta( "tracking" );
		echo $trackingcode;
	}

	/**
	 * スタイルシートのセレクターを取得
	 *
	 * @param string $type
	 */
	public function get_stylesheet_selector() {

		$buttoncolor       = "";
		$header_bgcolor    = static::$options["header_bgcolor"];
		$header_text_color = static::$options["header_text_color"];
		$body_bgcolor      = static::$options["default_bgcolor"];

		if (!is_array($body_bgcolor)) {
			$body_bgcolor = array(
				"single" => "",
				"top_color" => "",
				"bottom_color" => ""
			);
		}

		// 投稿ページの場合
		if ( static::$options['select_type'] == "post" && is_single() ) {
			$color        = static::$options["affiliate_color"];
			$buttoncolor  = static::$options["affiliate_button_color"];
			$body_bgcolor = static::$options["body_bgcolor"];
			// 比較ページの場合
		} else if ( static::$options['select_type'] == "compare" && is_single() ) {
			$color        = static::$options["compare_color"];
			$body_bgcolor = static::$options["body_bgcolor"];
			// lp
		} else if ( static::$options['select_type'] == "lp" && is_single() ) {
			$color        = static::$options["lp_color"];
			$body_bgcolor = static::$options["body_bgcolor"];
			// blog
		} else if ( static::$options['select_type'] == "blog" && is_single() ) {
			$color        = static::$options["blog_color"];

			// それ以外
		} else {
			$color             = get_theme_mod( 'theme_color',
				( static::$options["default_color"] ) ? static::$options["default_color"] : "#555" );
			$header_bgcolor    = static::$options["default_header_bgcolor"];
			$header_text_color = static::$options["default_header_text_color"];
		}


		if ( ! $color ) {
			$color = "#ff463c";
		}

		if ( is_array( $color ) ) {
			$top_color    = $color["top_color"];
			$bottom_color = $color["bottom_color"];
		}

		$convertColor = new Color( $color );
		$darkcolor    = "#" . $convertColor->darken( 20 );

		ob_start();
		?>
		<style type="text/css">
			<?php
			if ( $body_bgcolor["single"] === "true" ){
			  echo static::to_prop( 'body', 'background', $body_bgcolor["top_color"] );
			} else {
			  echo static::to_prop( 'body', 'background-image', "linear-gradient(to bottom, ". $body_bgcolor['top_color']." 0%, " . $body_bgcolor['bottom_color'] ." 55%, " . $body_bgcolor['bottom_color']  . " 100%)" );
			}

			echo static::to_prop( '.header-bgcolor', 'background', $header_bgcolor );
			echo static::to_prop( 'h1.header__logo', 'color', $header_text_color );

			echo static::to_prop( '.transform-bgcolor,.button', 'background', $color );
      echo static::to_prop( '.transform-color', 'color', $color );
      echo static::to_prop( '.compare-sort-btn .button-wrap.decs-active a.sort-btn:before', 'color', $color );
      echo static::to_prop( '.compare-sort-btn .button-wrap.acs-active a.sort-btn:after',   'color', $color );
			echo static::to_prop( '.transform-table th', 'background', $color );
			// echo static::to_prop( '.wrapper a,.widget-title,.heading--lg', 'color', $color );
			echo static::to_prop( '.widget-title,.heading--lg', 'color', $color );
			// echo static::to_prop( '.wrapper a:hover,.header a', 'color', $color );
			echo static::to_prop( '.single .footer__copyright,.sidebar .widget ul li:before', 'background',  $darkcolor );
			echo static::to_prop( '.transform-bgcolor, a.button', 'color', '#fff' );
			echo static::to_prop( 'a.affiliate-item__button', 'background', $buttoncolor );
			echo static::to_prop( '.l-main .widget-title, .sidebar .widget-title', 'border-left-color', $darkcolor );
			echo static::to_prop( '.hentry__category__text a,.hentry__title', 'color', $darkcolor );

			echo static::to_prop( '.is-blog h1, .is-blog h2, .is-blog h3, .is-blog h4, .is-blog h5, .is-blog h6 ', 'color', $color );
			echo static::to_prop( '.is-blog h1, .is-blog h2, .is-blog h3, .is-blog h4, .is-blog h5, .is-blog h6, .heading--lg', 'border-left-color', $darkcolor );
			?>
		</style>
		<?php

		$css = ob_get_contents();

		ob_clean();

		return $css;

	}

	/**
	 * スタイルシートをを出力
	 */
	public function render_stylesheet() {
		$css = $this->get_stylesheet_selector();
		echo $css;
	}

	public static function to_prop( $selector, $prop, $value ) {

		$return = "";

		if ( $value ) {
			$return = $selector . " { " . $prop . " : " . $value . " !important;" . "}";
		}

		return $return;
	}


}

$options = new CompareOptions();

