<?php

/**
 * Theme Activation Tour
 *
 * This class handles the pointers used in the introduction tour.
 * @package Popup Demo
 * @see https://gist.github.com/DevinWalker/7595475
 *
 */
class WP_Tour {

	private $tour = array();

	private $pointer_close_id = ''; //value can be cleared to retake tour

	/**
	 * 画面一覧
	 * @var array
	 */
	private $screens = array(

		'dashboard',
		'update-core',

		'edit',
		'post',

		'edit-category', // カテゴリ
		'edit-tags', // タグ

		'edit-page',
		'page',

		'edit-comments',
		'comment',

		'upload', // メディア
		'media', // メディアの新規追加

		'themes',
		'nav-menus',
		'theme-editor',
		'widgets',

		'plugins',
		'plugin-install',
		'plugin-editor',

		'users',
		'user', // ユーザーの新規追加
		'profile', // プロフィール

		'tools',

		'options-general',
		'options-writing',
		'options-discussion',
		'options-media',
		'options-permalink',
		'settings_page_tinymce-advanced',

		'toplevel_page_comparedefault',
	);

	/**
	 * WP_Tour constructor.
	 * 初期化
	 */
	public function __construct( $tour_id ) {
		global $wp_version;

		$this->pointer_tour_id = $tour_id;

		if ( version_compare( $wp_version, '3.4', '<' ) ) {
			return false;
		}

		add_action( 'admin_enqueue_scripts', array( $this, 'tour_enqueue' ) );
	}

	/**
	 * Enqueue styles and scripts needed for the pointers.
	 */
	public function tour_enqueue() {
		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		$enqueue_pointer_script_style = false;

		$dismissed_pointers = explode( ',', get_user_meta( get_current_user_id(), 'dismissed_wp_pointers', true ) );

		if ( ! in_array( $this->pointer_close_id, $dismissed_pointers ) ) {
			$enqueue_pointer_script_style = true;
			add_action( 'admin_print_footer_scripts', array( $this, 'intro_tour' ) );
			add_action( 'wp_footer', array( $this, 'intro_tour' ) );
		}

		if ( $enqueue_pointer_script_style ) {
			wp_enqueue_style( 'wp-pointer' );
			wp_enqueue_script( 'wp-pointer' );
		}
	}

	/**
	 * ツアーを追加する
	 *
	 * @param $settings
	 *
	 * @return object $this
	 */
	public function add_tour( $settings ) {

		$defaults   = array(
			array(
				array(
					'heading'  => "",
					'content'  => "",
					'id'       => '',
					'position' => "top",
					'align'    => "center",
					'button'   => '次へ',
					'next_url' => "",
					'function' => ''
				),
			),
		);
		$tour       = wp_parse_args( $settings, $defaults );
		$this->tour = array_merge( $tour, $this->tour );

		return $this;

	}

	/**
	 * ツアー内容の呼出
	 *
	 * $adminpages ツアー内容の配列
	 */
	public function intro_tour() {

		$page   = '';
		$screen = get_current_screen();

		if ( isset( $_GET['page'] ) ) {
			$page = $_GET['page'];
		}
		if ( empty( $page ) ) {
			$page = $screen->id;
		}
		$function = '';
		$button2  = '';
		$opt_arr  = array();
		if ( empty( $adminpages[ $page ] ) || ! $adminpages[ $page ] ) {
			return;
		}
		foreach ( $adminpages[ $page ] as $key => $option ) {
			//Location the pointer points
			if ( ! empty( $adminpages[ $page ][ $key ]['id'] ) ) {
				$id[ $key ] = $adminpages[ $page ][ $key ]['id'];
			} else {
				$id[ $key ] = $screen->id;
			}
			//Options array for pointer used to send to JS
			if ( '' != $page && in_array( $page, array_keys( $adminpages[ $page ] ) ) ) {
				$align           = ( is_rtl() ) ? 'right' : 'left';
				$opt_arr[ $key ] = array(
					'content'      => $adminpages[ $page ][ $key ]['content'],
					'position'     => array(
						'edge'  => ( ! empty( $adminpages[ $page ][ $key ]['position']['edge'] ) ) ? $adminpages[ $page ][ $key ]['position']['edge'] : 'left',
						'align' => ( ! empty( $adminpages[ $page ][ $key ]['position']['align'] ) ) ? $adminpages[ $page ][ $key ]['position']['align'] : $align
					),
					'pointerWidth' => 500
				);
				if ( isset( $adminpages[ $page ][ $key ]['button2'] ) ) {
					$button2[ $key ] = ( ! empty( $adminpages[ $page ][ $key ]['button2'] ) ) ? $adminpages[ $page ][ $key ]['button2'] : '';
				}
				if ( isset( $adminpages[ $page ][ $key ]['function'] ) ) {
					$function[ $key ] = $adminpages[ $page ][ $key ]['function'];
				}
			}
		}
		$this->print_scripts( $id, $opt_arr, __( "ツアーを終了", 'textdomain' ), $button2, $function );
	}

	/**
	 * Prints the pointer script
	 *
	 * @param string $selector The CSS selector the pointer is attached to.
	 * @param array $options The options for the pointer.
	 * @param string $button1 Text for button 1
	 * @param string|bool $button2 Text for button 2 (or false to not show it, defaults to false)
	 * @param string $button2_function The JavaScript function to attach to button 2
	 * @param string $button1_function The JavaScript function to attach to button 1
	 */
	public function print_scripts( $selectors, $options, $button1, $button2 = array(), $button2_function = '', $button1_function = '' ) {
		foreach ( $selectors as $key => $selector ) { ?>
			<script type="text/javascript">

				(function ($) {
					var wordimpress_pointer_options_<?php echo $key ?> = <?php echo json_encode( $options[$key] ); ?>, setup_<?php echo $key ?>;
					wordimpress_pointer_options_<?php echo $key ?> = $.extend(wordimpress_pointer_options_<?php echo $key ?>, {
						buttons: function (event, t) {
							button = $('<a id="pointer-close_<?php echo $key;?>" style="margin-left:5px" class="button-secondary">' + '<?php echo $button1; ?>' + '</a>');
							button.bind('click.pointer', function () {
								t.element.pointer('close');
							});
							return button;
						}
					});
					page_scroller = function (element) {
						var target = $(element).offset().top;
						$("html, body").animate({scrollTop: target}, 500);
						event.preventDefault();
						return false;
					}
					setup_<?php echo $key ?> = function () {
						$('<?php echo $selector; ?>').pointer(wordimpress_pointer_options_<?php echo $key ?>).pointer('open');
						<?php
						if ( $button2[$key] ) { ?>
						$('#pointer-close_<?php echo $key;?>').after('<a id="pointer-primary_<?php echo $key;?>" class="button-primary">' + '<?php echo $button2[$key]; ?>' + '</a>');
						<?php } ?>
						$('#pointer-primary_<?php echo $key;?>').click(function () {
							<?php echo $button2_function[$key]; ?>
						});
						$('#pointer-close_<?php echo $key;?>').click(function () {
							<?php if ( isset($button1_function[$key]) && $button1_function[$key] == '' ) { ?>
							$.post(ajaxurl, {
								pointer: '<?php echo $this->pointer_close_id; ?>',
								action: 'dismiss-wp-pointer'
							});
							<?php } else { ?>
							<?php echo isset($button1_function[$key]) ? $button1_function[$key]: ""; ?>
							<?php } ?>
						});
					};
					if (wordimpress_pointer_options_<?php echo $key ?>.position && wordimpress_pointer_options_<?php echo $key ?>.position.defer_loading) {
						$(window).bind('load.wp-pointers', setup_<?php echo $key ?>);
					} else {
						$(document).ready(setup_<?php echo $key ?>);
					}
				})(window.jQuery);

			</script>
			<?php
		}
	}
}

add_action( 'contextual_help', 'wptuts_screen_help', 10, 3 );
function wptuts_screen_help( $contextual_help, $screen_id, $screen ) {

	// The add_help_tab function for screen was introduced in WordPress 3.3.
	if ( ! method_exists( $screen, 'add_help_tab' ) ) {
		return $contextual_help;
	}

	global $hook_suffix;

	// List screen properties
	$variables = '<ul style="width:50%;float:left;"> <strong>Screen variables </strong>'
	             . sprintf( '<li> Screen id : %s</li>', $screen_id )
	             . sprintf( '<li> Screen base : %s</li>', $screen->base )
	             . sprintf( '<li>Parent base : %s</li>', $screen->parent_base )
	             . sprintf( '<li> Parent file : %s</li>', $screen->parent_file )
	             . sprintf( '<li> Hook suffix : %s</li>', $hook_suffix )
	             . '</ul>';

	// Append global $hook_suffix to the hook stems
	$hooks = array(
		"load-$hook_suffix",
		"admin_print_styles-$hook_suffix",
		"admin_print_scripts-$hook_suffix",
		"admin_head-$hook_suffix",
		"admin_footer-$hook_suffix"
	);

	// If add_meta_boxes or add_meta_boxes_{screen_id} is used, list these too
	if ( did_action( 'add_meta_boxes_' . $screen_id ) ) {
		$hooks[] = 'add_meta_boxes_' . $screen_id;
	}

	if ( did_action( 'add_meta_boxes' ) ) {
		$hooks[] = 'add_meta_boxes';
	}

	// Get List HTML for the hooks
	$hooks = '<ul style="width:50%;float:left;"> <strong>Hooks </strong> <li>' . implode( '</li><li>', $hooks ) . '</li></ul>';

	// Combine $variables list with $hooks list.
	$help_content = $variables . $hooks;

	// Add help panel
	$screen->add_help_tab( array(
		'id'      => 'wptuts-screen-help',
		'title'   => 'Screen Information',
		'content' => $help_content,
	) );

	return $contextual_help;
}

//new WP_Tour();
