<?php

/**
 * Class CompareCMB2
 * カスタムフィールドの設定
 */

/**
 * Returns options markup for a state select field.
 *
 * @param  mixed $value Selected/saved state
 *
 * @return string       html string containing all state options
 */
function cmb2_get_state_options( $value = false ) {
	$state_list = array( 'true' => '単一色として表示', 'false' => 'グラデーションとして表示' );

	$state_options = '';
	foreach ( $state_list as $abrev => $state ) {
		$state_options .= '<option value="' . $abrev . '" ' . selected( $value, $abrev,
				false ) . '>' . $state . '</option>';
	}

	return $state_options;
}

/**
 * Render Address Field
 */
function cmb2_render_bgcolorpicker_field_callback( $field, $value, $object_id, $object_type, $field_type ) {

	// make sure we specify each part of the value we need.
	$value = wp_parse_args( $value, array(
		'top_color'    => '#ffffff',
		'bottom_color' => '#ffffff',
		'linear'       => '',
		"desc"         => "",
		'single'       => "",
	) );

	if ( $value["single"] === "true" ) {
		$background = "background: " . $value["top_color"] . ";";
	} else {
		$background = "background-image: linear-gradient(to bottom, " . $value["top_color"] . " 0% , " . $value["bottom_color"] . " 100%);";
	}

	?>

	<div id="<?php echo $field_type->_id( '_canvas' ); ?>" style="width: 400px;height: 100px; <?php echo $background; ?> margin-bottom: 20px;"></div>
	<div>

		<label for="<?php echo $field_type->_id( '_single' ); ?>"></label>

		<?php
		echo @$field_type->select( array(
			'name'    => $field_type->_name( '[single]' ),
			'id'      => $field_type->_id( '_single' ),
			'value'   => $value['single'],
			"desc"    => "",
			"options" => cmb2_get_state_options( $value['single'] ),
		) );
		?>

		<label for="<?php echo $field_type->_id( '_top_color' ); ?>"></label>
		<?php echo $field_type->input( array(
			'name'  => $field_type->_name( '[top_color]' ),
			'id'    => $field_type->_id( '_top_color' ),
			'value' => $value['top_color'],
			"desc"  => ""
		) ); ?>
		<div style="display:none">
		<label for="<?php echo $field_type->_id( '_bottom_color' ); ?>"></label>
		<?php echo $field_type->input( array(
			'name'  => $field_type->_name( '[bottom_color]' ),
			'id'    => $field_type->_id( '_bottom_color' ),
			'value' => "#ffffff",
			"desc"  => ""
		) ); ?>
		</div>

	</div>
	<script type="text/javascript">
		(function ($) {
			"use strict";

			$(function () {
				var $target = $("#<?php echo $field_type->_id( '_canvas' ); ?>");
				var $type = $("#<?php echo $field_type->_id( '_single' ); ?> option:selected").val();

				var $top_color = "<?php echo $value['top_color']; ?>";
				var $bottom_color = "#ffffff";

				var $top_color_selector = "#<?php echo $field_type->_id( '_top_color' ); ?>";
				var $bottom_color_selector = "#<?php echo $field_type->_id( '_bottom_color' ); ?>";

				$($top_color_selector).wpColorPicker({
					change: function (e, t) {
						$top_color = t.color.toCSS();
						if ($type === "true") {
							$target[0].style.backgroundImage = "";
							$target[0].style.backgroundColor = $top_color;
						} else {
							var grad = 'linear-gradient(to bottom, ' + $top_color + ' 0%, ' + $bottom_color + ' 100%)';
							$target[0].style.backgroundImage = grad;
						}
					}
				});

				$("#<?php echo $field_type->_id( '_single' ); ?>").change(function () {
					$type = $(this).find("option:selected").val();
				});

				$($bottom_color_selector).wpColorPicker({
					change: function (e, t) {
						$bottom_color = t.color.toCSS();
						if ($type === "true") {
							return false;
						}
						var grad = 'linear-gradient(to bottom, ' + $top_color + ' 0%, ' + $bottom_color + ' 100%)';

						$target[0].style.backgroundImage = grad;
					}
				});
			});
		})(window.jQuery);

	</script>
	<?php
	//  echo $field_type->_desc( true );
}

add_filter( 'cmb2_render_bgcolorpicker', 'cmb2_render_bgcolorpicker_field_callback', 10, 5 );


add_shortcode( "lpbutton", "lpbutton" );

function lpbutton( $attrs, $content = "公式サイトはこちら" ) {
	$args = wp_parse_args( $attrs, array(
		'link' => "/",
		'text' => "公式サイトはこちら",
		'size' => "large",
		'type' => "normal",
		'color' => "#e12323",
	));

	ob_start();

	// ぷるぷるボタン
	if ($args['type'] == "prpr") {
		?>
		<div class="affiliate-item__prpr-button-wrap">
			<div class="actionBtn <?php echo $args["size"] ?>">
				<a href="<?php echo $args['link'] ?>" target="_blank" rel="nofollow" class="animate" style="<?php echo inlinePrprBtn($args["color"]) ?>"><?php echo $content ?></a>
				<img border="0" src="<?php echo get_template_directory_uri() ?>/assets/images/arrow.png" class="a-arrow">
			</div>
		</div>
		<?php

	// normalボタン
	} else {
		?>
		<div class="affiliate-item__button-wrap">
			<a href="<?php echo $args['link'] ?>" class="affiliate-item__button transform-bgcolor button <?php echo $args["size"] ?>" target="_blank" style="background:<?php echo $args["color"] ?> !important">
				<span><?php echo $content ?></span>
			</a>
		</div>
		<?php
	}
	$content = ob_get_contents();
	ob_end_clean();

	return $content;

}
function inlinePrprBtn($color) {
	$top_color    = $color;
	if(!$top_color) $top_color = "#42ff39";
	$bottom_color = gradient($top_color);
	$bg = "background: -webkit-gradient(linear, left top, left bottom, color-stop(0.00, ".$top_color."), color-stop(1.00, ".$bottom_color."));".
	      "background: -webkit-linear-gradient(".$top_color.", ".$bottom_color.");".
	      "background: -moz-linear-gradient(".$top_color.", ".$bottom_color.");".
	      "background: -o-linear-gradient(".$top_color.", ".$bottom_color.");".
	      "background: -ms-linear-gradient(".$top_color.", ".$bottom_color.");".
	      "background: linear-gradient(".$top_color.", ".$bottom_color.");";

	return $bg.
	'" onmouseover="ppcEvoDataLastPrprBtnColor=this.style.background;'.
	               'this.style.background=\''.gradient($top_color,  0.98).'\'"'.
	 ' onmouseout="this.style.background=ppcEvoDataLastPrprBtnColor';
}