<?php
/**
 * テーマカスタマイザーの設定
 * =====================================================
 * @package  epigone
 * @license  GPLv2 or later
 * @since 1.2.0
 * =====================================================''
 */
/**
 * テーマカスタマイザーを拡張
 * @since 1.2.0
 */
function epigone_customizer_settings() {


	/**
	 * 02. テーマカラー
	 */
	$settings['epigone_theme_color'] = array(
		'title'   => __( 'テーマのスタイル', 'epigone' ), // Panel title
		'section' => array(
			// theme color section
			'epigone_theme_color' => array(
				'title'       => __( 'テーマカラー', 'epigone' ),
				'description' => __( 'テーマカラーの設定をしてください', 'epigone' ),
				'setting'     => array(
					'theme_color' => array(
						'label'               => __( 'テーマカラー', 'epigone' ),
						'default'             => '#fff',
						'type'                => 'color',
						'sanitaize_call_back' => '',
					),
				),
			),
		),
	);



	/**
	 * 03. Layout
	 */
	$settings['epigone_layout'] = array(
		'title'       => __( 'レイアウト設定', 'epigone' ), // Panel title
		'description' => __( 'レイアウトの設定を行ってください。', 'epigone' ),
		'section'     => array(
			'epigone_layout_top'    => array(
				'title'       => __( 'レイアウト', 'epigone' ),
//				'description' => __( 'Please select the layout.', 'epigone' ),
				'setting'     => array(
					'epigone_layout' => array(
//						'label'               => __( 'Layout of top page', 'epigone' ),
						'default'             => 'l-right-sidebar',
						'type'                => 'layout-picker',
						'sanitaize_call_back' => '',
					),
				)
			),
		)
	);

	return $settings;
}

add_filter( 'epigone_theme_customizer_settings', 'epigone_customizer_settings', 1 );

/**
 * Theme Scroll top
 * @since 1.2.0
 */

function epigone_scroll_top() {
	if ( 'true' === get_theme_mod( 'scroll_display', false ) ) {
		echo '<div id="scroll-top"><a href="#"><i class="fa fa-angle-up"></i></a></div>';
	}
}

add_action( 'get_footer', 'epigone_scroll_top' );

/**
 * Google Analytics - Tracking
 * @since 1.2.0
 */

function epigone_tracking_code() {
	$traking_code = get_theme_mod( 'tracking_code', false );
	if ( $traking_code ) {
		echo '<!-- Google Analytics -->
' . $traking_code .
		     '
';
	}
}

add_action( 'wp_footer', 'epigone_tracking_code' );

/**
 * output meta tag to wp_head
 * @since 1.2.0
 */

function epigone_meta_tag() {

	$meta_tag         = '';
	$meta_description = get_theme_mod( 'meta_description', false );
	$meta_keyword     = get_theme_mod( 'meta_keyword', false );

	if ( $meta_description ) {
		$meta_tag .= '<meta name="description" content="' . esc_html( $meta_description ) . '">' . "\n";
	}

	if ( $meta_keyword ) {
		$meta_tag .= '<meta name="keywords" content="' . esc_html( $meta_keyword ) . '">' . "\n";
	}

	echo $meta_tag;

}

add_action( 'wp_head', 'epigone_meta_tag', 10 );

/**
 * output favicon tag to wp_head
 * @since 1.2.0
 */

function epigone_favicon() {

	$favicon_tag = '';
	$favicon     = get_theme_mod( 'meta_favicon', false );


	if ( $favicon ) {
		$favicon_tag .= '<link rel="shortcut icon" href="' . esc_url( $favicon ) . '">' . "\n";
	}

	echo $favicon_tag;

}

add_action( 'wp_head', 'epigone_favicon', 10 );


/**
 * 抜粋の文字数を制限
 *
 * @param $length
 *
 * @return string
 */
function epigone_excerpt_length( $length ) {
	$thememod = get_theme_mod( 'single_char_num', $length );

	return $thememod;
}

add_filter( 'excerpt_length', 'epigone_excerpt_length', 999 );


/**
 * body タグに付与するクラスを調整
 *
 * @param $classes
 *
 * @return mixed
 */
function epigone_body_class( $classes ) {
	$layout = get_theme_mod( 'epigone_layout', 'l-right-sidebar' );
	$select_type = get_post_meta( get_the_ID(), 'select_type', true );

	$class = "";
	if ( is_home() || is_front_page() || is_archive() || is_page() || $select_type == "blog") {
		$class = $layout;
	} else {
		$class = "l-full";
	}
	$classes[] = $class;

	return $classes;
}

add_filter( 'body_class', 'epigone_body_class' );
