<?php
/**
 * Setup script for this theme
 * =====================================================
 * @package  epigone
 * @license  GPLv2 or later
 * @since 1.0.0
 * =====================================================''
 */

/**
 * テーマのセットアップ
 * @return void
 */


function epigone_setup()
{

    load_theme_textdomain('epigone', get_template_directory() . '/languages');
    load_theme_textdomain('tgmpa', get_template_directory() . '/languages');

    // automatic feed をサポート
    add_theme_support('automatic-feed-links');

    // パンくず をサポート
    add_theme_support('epigone-breadcrumbs');

    // ページネーション をサポート
    add_theme_support('epigone-pagination');

    // アイキャッチ画像のサポート
    add_theme_support('post-thumbnails');

    // メニューのサポート
    add_theme_support('menus');

    // タイトルタグをサポート
    add_theme_support('title-tag');

    // HTML5構造化マークアップで出力
    add_theme_support(
        'html5',
        array(
            'comment-list',
            'search-form',
            'comment-form',
            'gallery',
            'caption',
        )
    );

    // ヘッダーナビゲーションを登録
    register_nav_menus(array('primary' => __('Header Primary Navigation', 'epigone')));

    $my_theme = wp_get_theme();
    // editor-style を登録
    add_editor_style('assets/css/editor-style.css', null, $my_theme->get( 'Version' ));

}

add_action('after_setup_theme', 'epigone_setup');

/**
 * wp_head() で出力されるタグの調整
 *
 * @return void
 */
function epigone_head_cleanup()
{

    remove_action('wp_head', 'feed_links', 2);
    remove_action('wp_head', 'feed_links_extra', 3);
    remove_action('wp_head', 'rsd_link');
    remove_action('wp_head', 'wlwmanifest_link');
    remove_action('wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);
    remove_action('wp_head', 'wp_generator');
    remove_action('wp_head', 'wp_shortlink_wp_head', 10, 0);

    global $wp_widget_factory;

    remove_action('wp_head',
        array(
            $wp_widget_factory->widgets['WP_Widget_Recent_Comments'],
            'recent_comments_style',
        )
    );
}

add_filter('init', 'epigone_head_cleanup', 10);


/**
 * アバターの取得
 *
 * @param  string $avatar
 * @param  string $type
 *
 * @return string
 */

function epigone_get_avatar($avatar, $type)
{

    if ( ! is_object($type)) {
        return $avatar;
    }

    $avatar = str_replace("class='avatar", "class='avatar left media-object", $avatar);

    return $avatar;

}

add_filter('get_avatar', 'epigone_get_avatar', 10, 2);

/**
 * 検索テンプレートを変更
 *
 * @param $form string
 *
 * @return string フォームのHTML
 */
function epinoge_search_form($form)
{

    ob_start();
    get_template_part('modules/searchform');
    $form = ob_get_clean();

    return $form;

}

add_filter('get_search_form', 'epinoge_search_form');


/**
 * パンくずの読み込み
 *
 * @return void
 */
function epigone_include_breadcrumbs()
{

//	if ( current_theme_supports( 'epigone-breadcrumbs' ) ) {
//		get_template_part( 'modules/breadcrumbs' );
//	}

}

add_action('get_footer', 'epigone_include_breadcrumbs');

/**
 * 特定商取引法に基づく表記ページが存在するかどうか調べる
 * @return boolean
 */
function is_epigone_tokusho()
{
    global $wpdb;
    $sql = "SELECT ID FROM $wpdb->posts WHERE post_name=\"company\"";
    if ( ! get_option('rws_tokushou_flag')) {
        return false;
    }
    $results = $wpdb->get_results($sql);
    if (is_array($results) || $results) {
        update_option('rws_tokushou_flag', true);

        return $results[0]->ID;
    } else {
        return false;
    }
}

/**
 * 特定商取引法に基づく表記ページがない場合は、自動的に作成する
 * @return void
 */
function epigone_create_page()
{

    if (get_option('epigone_order_id')) {
        return;
    }

    $post_attr = array(
        'post_title'   => '運営者について',
        'post_name'    => 'order',
        'post_type'    => 'page',
        'post_content' => '',
        'post_status'  => 'publish',
        'post_author'  => 1,
    );

    $post_id = wp_insert_post($post_attr);

    // 投稿に成功した場合、カスタムフィールド情報を付与
    if ($post_id) {
        update_post_meta($post_id, '_wp_page_template', 'page-order.php');
        update_post_meta($post_id, 'order_1', get_bloginfo('name'));
        update_post_meta($post_id, 'order_2', '各、販売者サイトに準ずる');
        update_post_meta($post_id, 'order_3', '各、販売者サイトに準ずる');
        update_post_meta($post_id, 'order_4', '各、販売者サイトに準ずる');
        update_post_meta($post_id, 'order_5', '各、販売者サイトに準ずる');
        update_post_meta($post_id, 'order_6', '各、販売者サイトに準ずる');
        update_post_meta($post_id, 'order_7', '各、販売者サイトに準ずる');
        update_post_meta($post_id, 'order_8', '各、販売者サイトに準ずる');
        update_post_meta($post_id, 'order_9',
            'サイトは、アフィリエイトプログラムにより商品をご紹介致しております。 アフィリエイトプログラムとは、商品及びサービスの提供元と業務提携を結び 商品やサービスを紹介するインターネット上のシステムです。 従いまして、当サイトの商品は当サイトが販売している訳ではありません。 お客様ご要望の商品、お支払い等はリンク先の販売店と直接のお取引となりますので、 特商法に基づく表記につきましてはリンク先をご確認頂けます様お願い致します。 商品の価格 商品の詳細 消費税 送料 在庫数等の詳細は時として変わる場合も御座います。 当サイトだけではなくリンク先のサイトもよくご確認頂けます様お願い致します。 また、当サイトの掲載情報をご利用頂く場合には、 お客様のご判断と責任におきましてご利用頂けます様お願い致します。 当サイトでは、一切の責任を負いかねます事ご了承願います。 尚、掲載商品に関するお問合せはリンク先に御座います企業宛までお願い致します。 当サイト管理者側ではお答え致しかねます事、ご了承ください。');
        update_option('epigone_order_id', $post_id);
    }


}

add_action('admin_init', 'epigone_create_page', 10, 0);


// TinyMCE Advanced の設定を上書き
add_action('admin_init', "udpate_tadv_admin_settings");

function udpate_tadv_admin_settings()
{

    $tadv_settings = get_option("tadv_admin_settings");


    if ($tadv_settings) {
        $tadv_settings["options"] = "no_autop";
    }
    update_option("tadv_admin_settings", $tadv_settings);

}


